"""
======================
反向Cuthill--McKee算法
======================

矩阵的Cuthill-McKee排序

反向Cuthill--McKee算法提供了一种稀疏矩阵排序方法，可以减少矩阵的带宽。
"""

import numpy as np
import matplotlib.pyplot as plt
import seaborn as sns
import networkx as nx


# 构建低带宽矩阵
G = nx.grid_2d_graph(3, 3)
rcm = list(nx.utils.reverse_cuthill_mckee_ordering(G))
print("ordering", rcm)

print("unordered Laplacian matrix")
A = nx.laplacian_matrix(G)
x, y = np.nonzero(A)
# 打印(f"较低的带宽: {(y - x).max()}")
# 打印(f"上带宽: {(x - y).max()}")
print(f"bandwidth: {(y - x).max() + (x - y).max() + 1}")
print(A)

B = nx.laplacian_matrix(G, nodelist=rcm)
print("low-bandwidth Laplacian matrix")
x, y = np.nonzero(B)
# 打印(f"较低的带宽: {(y - x).max()}")
# 打印(f"上带宽: {(x - y).max()}")
print(f"bandwidth: {(y - x).max() + (x - y).max() + 1}")
print(B)

sns.heatmap(B.todense(), cbar=False, square=True, linewidths=0.5, annot=True)
plt.show()
