"""
===========
Erdos Renyi
===========

创建一个具有n个节点和m条边的G{n,m}随机图，并报告一些属性。

这个图有时被称为Erdős-Rényi图，但它与G{n,p}或二项图不同，后者有时也被称为Erdős-Rényi图。
"""

import matplotlib.pyplot as plt
import networkx as nx

n = 10  # 10个节点
m = 20  # 20条边
seed = 20160  # 为可重复性初始化随机数生成器

# 使用种子以确保可重复性
G = nx.gnm_random_graph(n, m, seed=seed)

# 一些属性
print("node degree clustering")
for v in nx.nodes(G):
    print(f"{v} {nx.degree(G, v)} {nx.clustering(G, v)}")

print()
print("the adjacency list")
for line in nx.generate_adjlist(G):
    print(line)

pos = nx.spring_layout(G, seed=seed)  # 用于可重复布局的种子
nx.draw(G, pos=pos)
plt.show()
