"""
========
足球网络
========

加载GML格式的足球网络并计算一些网络统计数据。

演示如何下载压缩文件中的GML图，解压缩并加载到NetworkX图中。

需要互联网连接以下载URL
http://www-personal.umich.edu/~mejn/netdata/football.zip
"""

import urllib.request
import io
import zipfile

import matplotlib.pyplot as plt
import networkx as nx

url = "http://www-personal.umich.edu/~mejn/netdata/football.zip"

sock = urllib.request.urlopen(url)  # open URL
s = io.BytesIO(sock.read())  # read into BytesIO "file"
sock.close()

zf = zipfile.ZipFile(s)  # zipfile object
txt = zf.read("football.txt").decode()  # read info file
gml = zf.read("football.gml").decode()  # read gml data
# 丢弃带有 # 的虚假第一行，来自 mejn 文件
gml = gml.split("\n")[1:]
G = nx.parse_gml(gml)  # parse gml data

print(txt)
# 打印每个队伍的比赛场次数
for n, d in G.degree():
    print(f"{n:20} {d:2}")

options = {"node_color": "black", "node_size": 50, "linewidths": 0, "width": 0.1}

pos = nx.spring_layout(G, seed=1969)  # 用于可重复布局的种子
nx.draw(G, pos, **options)
plt.show()
